package Nix::Config;

use MIME::Base64;

$version = "1.11";

$binDir = $ENV{"NIX_BIN_DIR"} || "/nix/store/90rq3xc6xv5hn4cxm8br69iw5i74vmbn-nix-1.11/bin";
$libexecDir = $ENV{"NIX_LIBEXEC_DIR"} || "/nix/store/90rq3xc6xv5hn4cxm8br69iw5i74vmbn-nix-1.11/libexec";
$stateDir = $ENV{"NIX_STATE_DIR"} || "/nix/var/nix";
$manifestDir = $ENV{"NIX_MANIFESTS_DIR"} || "/nix/var/nix/manifests";
$logDir = $ENV{"NIX_LOG_DIR"} || "/nix/var/log/nix";
$confDir = $ENV{"NIX_CONF_DIR"} || "/etc/nix";
$storeDir = $ENV{"NIX_STORE_DIR"} || "/nix/store";

$bzip2 = "/nix/store/9qq1ija0vjpaf4yfqdd3g92q5xqsaixy-bzip2-1.0.6/bin/bzip2";
$xz = "/nix/store/hs8lf8v9qqfs9m3jqmm97nqg7wg9dqjw-xz-5.2.1/bin/xz";
$curl = "/nix/store/vfnzw6j99xbk96n22mp3h9mana3c19id-curl-7.44.0/bin/curl";
$openssl = "/nix/store/3b4ii2sf651iih5161l7l9hdi9zivbz5-openssl-1.0.1q/bin/openssl";

$useBindings = "yes" eq "yes";

%config = ();

%binaryCachePublicKeys = ();

$defaultPublicKeys = "cache.nixos.org-1:6NCHdD59X431o0gWypbMrAURkbJ16ZPMQFGspcDShjY=";

sub readConfig {
    if (defined $ENV{'_NIX_OPTIONS'}) {
        foreach my $s (split '\n', $ENV{'_NIX_OPTIONS'}) {
            my ($n, $v) = split '=', $s, 2;
            $config{$n} = $v;
        }
    } else {
        my $config = "$confDir/nix.conf";
        return unless -f $config;

        open CONFIG, "<$config" or die "cannot open ‘$config’";
        while (<CONFIG>) {
            /^\s*([\w\-\.]+)\s*=\s*(.*)$/ or next;
            $config{$1} = $2;
        }
        close CONFIG;
    }

    foreach my $s (split(/ /, $config{"binary-cache-public-keys"} // $defaultPublicKeys)) {
        my ($keyName, $publicKey) = split ":", $s;
        next unless defined $keyName && defined $publicKey;
        $binaryCachePublicKeys{$keyName} = decode_base64($publicKey);
    }
}

return 1;
